@@ -1,4 +1,4 @@
-# $Id: install.py 1758 2017-10-10 10:17:55Z mwall $
+# $Id: install.py 1790 2019-01-10 05:31:32Z mwall $
 # installer for the forecast extension
 # Copyright 2014-2016 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.2.18",
+            version="3.2.20",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -22,6 +22,7 @@ class ForecastInstaller(ExtensionInstaller):
                               'user.forecast.UKMOForecast',
                               'user.forecast.AerisForecast',
                               'user.forecast.WWOForecast',
+                              'user.forecast.DSForecast',
                               'user.forecast.XTideForecast'],
             config={
                 'Forecast': {
@@ -45,6 +46,8 @@ class ForecastInstaller(ExtensionInstaller):
                         'client_secret': 'INSERT_AERIS_CLIENT_SECRET_HERE'},
                     'WWO': {
                         'api_key': 'INSERT_WWO_API_KEY_HERE'}},
+                    'DS': {
+                        'api_key': 'INSERT_DS_API_KEY_HERE'},
                 'DataBindings': {
                     'forecast_binding': {
                         'database': 'forecast_sqlite'}},
@@ -75,10 +78,12 @@ class ForecastInstaller(ExtensionInstaller):
                      'skins/forecast/forecast_table.inc',
                      'skins/forecast/compact.html.tmpl',
                      'skins/forecast/iconic.html.tmpl',
+                     'skins/forecast/iconic-horizontal.html.tmpl',
                      'skins/forecast/index.html.tmpl',
                      'skins/forecast/multiple-strips.html.tmpl',
                      'skins/forecast/multiple-tables.html.tmpl',
                      'skins/forecast/single-strip.html.tmpl',
+                     'skins/forecast/single-strip-vertical.html.tmpl',
                      'skins/forecast/single-table.html.tmpl',
                      'skins/forecast/tides.html.tmpl',
                      'skins/forecast/zambretti.html.tmpl']),
